You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flex.apache.org by er...@apache.org on 2015/01/15 12:45:09 UTC

[19/19] git commit: [flex-sdk] [refs/heads/develop] - Switch to version 16.0 players (Flash and AIR)

Switch to version 16.0 players (Flash and AIR)

Signed-off-by: Erik de Bruin <er...@ixsoftware.nl>


Project: http://git-wip-us.apache.org/repos/asf/flex-sdk/repo
Commit: http://git-wip-us.apache.org/repos/asf/flex-sdk/commit/d7aea2e7
Tree: http://git-wip-us.apache.org/repos/asf/flex-sdk/tree/d7aea2e7
Diff: http://git-wip-us.apache.org/repos/asf/flex-sdk/diff/d7aea2e7

Branch: refs/heads/develop
Commit: d7aea2e70a1f4abb7d346ec21a37edd4aadbddd6
Parents: 5efaf63
Author: Erik de Bruin <er...@ixsoftware.nl>
Authored: Thu Jan 15 10:07:22 2015 +0100
Committer: Erik de Bruin <er...@ixsoftware.nl>
Committed: Thu Jan 15 12:44:19 2015 +0100

----------------------------------------------------------------------
 README                                    | 20 ++++++++++----------
 RELEASE_NOTES                             |  4 ++--
 build.properties                          |  2 +-
 ide/checkAllPlayerGlobals.sh              |  3 ++-
 ide/flashbuilder/makeApacheFlexForIDE.bat | 16 ++++++++--------
 ide/flashbuilder/makeApacheFlexForIDE.sh  | 14 +++++++-------
 ide/setFlashPlayerVersion.sh              |  6 ++++--
 jenkins.xml                               |  9 ++++++++-
 8 files changed, 42 insertions(+), 32 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/README
----------------------------------------------------------------------
diff --git a/README b/README
index 2711f7c..64374cf 100644
--- a/README
+++ b/README
@@ -144,11 +144,11 @@ and you will get compile errors.
 * 3)
 The Adobe AIR integration kit for Windows can be downloaded from:
 
-   http://airdownload.adobe.com/air/win/download/15.0/AdobeAIRSDK.zip
+   http://airdownload.adobe.com/air/win/download/16.0/AdobeAIRSDK.zip
 
 The Adobe AIR integration kit for Mac can be downloaded from:
 
-    http://airdownload.adobe.com/air/mac/download/15.0/AdobeAIRSDK.tbz2
+    http://airdownload.adobe.com/air/mac/download/16.0/AdobeAIRSDK.tbz2
 
 The Adobe AIR integration kit for Linux can be downloaded from:
 
@@ -157,9 +157,9 @@ The Adobe AIR integration kit for Linux can be downloaded from:
 Download the AIR SDK for your platform and unzip it. Set AIR_HOME to the
 absolute path of the AIR SDK directory.
 
-This version of the Apache Flex SDK was certified for use with Adobe AIR 15
+This version of the Apache Flex SDK was certified for use with Adobe AIR 16
 and is compatible with version 3.1 and up. It has been fully tested on AIR 3.7,
-4 and 15.
+4 and 16.
 
 * 4)
 The Adobe Flash Player content debuggers can be found here:
@@ -168,7 +168,7 @@ The Adobe Flash Player content debuggers can be found here:
 
 This version of the Apache Flex SDK was certified for use with Adobe Flash
 Player 11.1, and is compatible with version 10.2 and up. It has been tested
-with versions 11.1, 11.7, 13.0 and 15.0 on Windows and Mac. It has been
+with versions 11.1, 11.7, 13.0 and 16.0 on Windows and Mac. It has been
 compiled, but not fully tested, against other Adobe Flash Player versions.
 It has not been fully tested on Linux.
 
@@ -326,13 +326,13 @@ To create an SDK for Flash Builder or any other IDE, run:
 If you want to set the Flash Player and AIR versions to something other
 than their defaults, pass the verisons to the ant script like so:
 
-     ant -f installer.xml -Dflash.sdk.version=15.0 -Dair.sdk.version=15.0
+     ant -f installer.xml -Dflash.sdk.version=16.0 -Dair.sdk.version=16.0
 
 On Mac/Linux the AIR and Flash Player version can be changed, after the SDK
 has been compiled, by running:
 
-    ./ide/setFlashPlayerVersion.sh ./ 15.0
-    ./ide/addAIRtoSDK.sh 15.0 ./
+    ./ide/setFlashPlayerVersion.sh ./ 16.0
+    ./ide/addAIRtoSDK.sh 16.0 ./
 
 
 
@@ -414,9 +414,9 @@ OR
 Change the playerglobal.version in the build.properties file to have a value
 other than '11.1'. For this change to take effect, the SDK needs to be
 recompiled. For example, to compile against the latest version of the Adobe
-Flash Player, set the value of playerglobal.version to be '15.0' like so:
+Flash Player, set the value of playerglobal.version to be '16.0' like so:
 
-    playerglobal.version = 15.0
+    playerglobal.version = 16.0
 
 OR
 

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/RELEASE_NOTES
----------------------------------------------------------------------
diff --git a/RELEASE_NOTES b/RELEASE_NOTES
index b20a69f..89a111b 100644
--- a/RELEASE_NOTES
+++ b/RELEASE_NOTES
@@ -14,8 +14,8 @@ New Features
 
 AIR and Flash Player Support
 ----------------------------
-- Support Flash Player 15.0 and 16.0 beta
-- Support for AIR 15.0 and 16.0 beta
+- Support Flash Player 16.0
+- Support for AIR 16.0
 
 Bug Fixes
 ---------

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/build.properties
----------------------------------------------------------------------
diff --git a/build.properties b/build.properties
index c7e0c2c..c2c7d51 100644
--- a/build.properties
+++ b/build.properties
@@ -28,7 +28,7 @@ build.number = 0
 playerglobal.version = 11.1
 
 # AIR version number
-air.version = 15.0
+air.version = 16.0
 
 # Default locale for the SDK
 locale = en_US

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/ide/checkAllPlayerGlobals.sh
----------------------------------------------------------------------
diff --git a/ide/checkAllPlayerGlobals.sh b/ide/checkAllPlayerGlobals.sh
index 84a2a47..c6e34bd 100755
--- a/ide/checkAllPlayerGlobals.sh
+++ b/ide/checkAllPlayerGlobals.sh
@@ -124,4 +124,5 @@ downloadPlayerGlobal 12.0 1a7b05bb2c776de38197113e40667126 http://download.macro
 downloadPlayerGlobal 13.0 07db042296350b04ae19e98f64a55ea1 http://download.macromedia.com/get/flashplayer/updaters/13/playerglobal13_0.swc
 downloadPlayerGlobal 14.0 6858e63b1ff8373a1a3c1c60b36c9fc9 http://download.macromedia.com/get/flashplayer/updaters/14/playerglobal14_0.swc
 downloadPlayerGlobal 15.0 4d17b14ef74dd23377a71a3fdbfda8ad http://download.macromedia.com/get/flashplayer/updaters/15/playerglobal15_0.swc
-downloadPlayerGlobal 16.0 f81045c8a6fdde1ed4952d6622355580 http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer16_playerglobal.swc
+downloadPlayerGlobal 16.0 793237cdc018c8a8115578664c724b09 http://download.macromedia.com/get/flashplayer/updaters/16/playerglobal16_0.swc
+#downloadPlayerGlobal 16.0 f81045c8a6fdde1ed4952d6622355580 http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer16_playerglobal.swc

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/ide/flashbuilder/makeApacheFlexForIDE.bat
----------------------------------------------------------------------
diff --git a/ide/flashbuilder/makeApacheFlexForIDE.bat b/ide/flashbuilder/makeApacheFlexForIDE.bat
index a00e598..1a68154 100755
--- a/ide/flashbuilder/makeApacheFlexForIDE.bat
+++ b/ide/flashbuilder/makeApacheFlexForIDE.bat
@@ -42,10 +42,10 @@ REM
 set APACHE_FLEX_BIN_DISTRO_DIR=..\..
 
 REM
-REM     Adobe AIR SDK Version 15.0
+REM     Adobe AIR SDK Version 16.0
 REM
 set ADOBE_AIR_SDK_WIN_FILE=AdobeAIRSDK.zip
-set ADOBE_AIR_SDK_WIN_URL=http://airdownload.adobe.com/air/win/download/15.0/%ADOBE_AIR_SDK_WIN_FILE%
+set ADOBE_AIR_SDK_WIN_URL=http://airdownload.adobe.com/air/win/download/16.0/%ADOBE_AIR_SDK_WIN_FILE%
 
 REM
 REM     Adobe Flash Player Version 11.1
@@ -53,9 +53,9 @@ REM
 set ADOBE_FB_GLOBALPLAYER_11_1_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
 
 REM
-REM     Adobe Flash Player Version 15.0
+REM     Adobe Flash Player Version 16.0
 REM
-set ADOBE_FB_GLOBALPLAYER_15_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal15_0.swc
+set ADOBE_FB_GLOBALPLAYER_16_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/16/playerglobal16_0.swc
 
 :getDir
 if not [%1] == [] goto checkJar
@@ -124,13 +124,13 @@ cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_11_1_SWC_URL%" "%FB_GLO
 if %errorlevel% neq 0 goto errorExit
 
 REM
-REM     Download 15.0 playerglobal.swc
+REM     Download 16.0 playerglobal.swc
 REM
-set FB_GLOBALPLAYER_DIR=%FLEX_HOME%\frameworks\libs\player\15.0
+set FB_GLOBALPLAYER_DIR=%FLEX_HOME%\frameworks\libs\player\16.0
 if not exist "%FB_GLOBALPLAYER_DIR%" mkdir "%FB_GLOBALPLAYER_DIR%"
 
-echo Downloading Adobe Flash Player playerglobal.swc from "%ADOBE_FB_GLOBALPLAYER_15_0_SWC_URL%" to "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
-cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_15_0_SWC_URL%" "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
+echo Downloading Adobe Flash Player playerglobal.swc from "%ADOBE_FB_GLOBALPLAYER_16_0_SWC_URL%" to "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
+cscript //B //nologo winUtil.vbs "%ADOBE_FB_GLOBALPLAYER_16_0_SWC_URL%" "%FB_GLOBALPLAYER_DIR%\playerglobal.swc"
 if %errorlevel% neq 0 goto errorExit
 
 REM

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/ide/flashbuilder/makeApacheFlexForIDE.sh
----------------------------------------------------------------------
diff --git a/ide/setFlashPlayerVersion.sh b/ide/setFlashPlayerVersion.sh
index 8bcf77e..5318f91 100755
--- a/ide/setFlashPlayerVersion.sh
+++ b/ide/setFlashPlayerVersion.sh
@@ -99,15 +99,17 @@ determineVersion()
         then 
             FLASH_VERSION="11.1"
         else
-            FLASH_VERSION="15.0"
+            FLASH_VERSION="16.0"
         fi
     fi
     
     if [ ${latest} = "Y" ]
     then
-    	FLASH_VERSION="15.0"
+    	FLASH_VERSION="16.0"
     fi
     
+    # (erikdebruin) How does this work if the beta and release have the same
+    #               major.minor version?
     if [ ${useBeta} = "Y" ]
     then
     	FLASH_VERSION="16.0"

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/jenkins.xml
----------------------------------------------------------------------
diff --git a/jenkins.xml b/jenkins.xml
index 3ea47ae..3e9edb9 100644
--- a/jenkins.xml
+++ b/jenkins.xml
@@ -226,10 +226,17 @@
 
     <target name="playerglobal16.0-download" if="target16.0">
     	<mkdir dir="${basedir}/lib/player/${playerglobal.version}"/>
-        <get src="http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer16_playerglobal.swc" 
+        <get src="http://download.macromedia.com/get/flashplayer/updaters/16/playerglobal16_0.swc" 
             dest="${basedir}/lib/player/${playerglobal.version}/playerglobal.swc" 
             verbose="false"/>
     </target>
+
+    <!-- target name="playerglobal16.0-download" if="target16.0">
+    	<mkdir dir="${basedir}/lib/player/${playerglobal.version}"/>
+        <get src="http://labsdownload.adobe.com/pub/labs/flashruntimes/flashplayer/flashplayer16_playerglobal.swc" 
+            dest="${basedir}/lib/player/${playerglobal.version}/playerglobal.swc" 
+            verbose="false"/>
+    </target -->
             	
     <target name="clean" description="Cleans third party downloaded files.">
     	<delete dir="${FLEX_HOME}/temp" />
diff --git a/ide/flashbuilder/makeApacheFlexForIDE.sh b/ide/flashbuilder/makeApacheFlexForIDE.sh
index a0b3af3..f96a147 100755
--- a/ide/flashbuilder/makeApacheFlexForIDE.sh
+++ b/ide/flashbuilder/makeApacheFlexForIDE.sh
@@ -38,12 +38,12 @@
 # Apache Flex binary distribution
 APACHE_FLEX_BIN_DIR="$( cd $( dirname -- "$0" ) > /dev/null ; pwd )"/../..
 
-# Adobe AIR SDK Version 15.0
-ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/15.0/AdobeAIRSDK.tbz2
+# Adobe AIR SDK Version 16.0
+ADOBE_AIR_SDK_MAC_URL=http://airdownload.adobe.com/air/mac/download/16.0/AdobeAIRSDK.tbz2
 
 # Adobe Flash Player Version 11.1
 ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/11/playerglobal11_1.swc
-ADOBE_FLASHPLAYER_GLOBALPLAYER_15_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/15/playerglobal15_0.swc
+ADOBE_FLASHPLAYER_GLOBALPLAYER_16_0_SWC_URL=http://fpdownload.macromedia.com/get/flashplayer/updaters/16/playerglobal16_0.swc
 
 # Adobe Flex SDK v4.6
 ADOBE_FLEX_SDK_URL=http://fpdownload.adobe.com/pub/flex/sdk/builds/flex4.6/flex_sdk_4.6.0.23201B.zip
@@ -104,10 +104,10 @@ echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GL
 mkdir -p "$FLEX_HOME/frameworks/libs/player/11.1"
 curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_11_1_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/11.1/playerglobal.swc"
 
-# download 15 playerglobal.swc
-echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GLOBALPLAYER_15_0_SWC_URL"
-mkdir -p "$FLEX_HOME/frameworks/libs/player/15.0"
-curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_15_0_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/15.0/playerglobal.swc"
+# download 16 playerglobal.swc
+echo "Downloading Adobe Flash Player playerglobal.swc from $ADOBE_FLASHPLAYER_GLOBALPLAYER_16_0_SWC_URL"
+mkdir -p "$FLEX_HOME/frameworks/libs/player/16.0"
+curl "$ADOBE_FLASHPLAYER_GLOBALPLAYER_16_0_SWC_URL" --output "$FLEX_HOME/frameworks/libs/player/16.0/playerglobal.swc"
 
 # copy the config files formatted for Flash Builder to frameworks 
 echo "Installing the frameworks config files configured for use with Adobe Flash Builder"

http://git-wip-us.apache.org/repos/asf/flex-sdk/blob/d7aea2e7/ide/setFlashPlayerVersion.sh
----------------------------------------------------------------------